/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 *  FLINES.HPP -- line class declarations              V1.0  *
 *                                                           *
 *  Operations:                                              *
 *  - Constructs class objects with public member string     *
 *    objects and input stream pointers.                     *
 *  Assumptions:                                             *
 *  - flines.hpp header file will be included with any C++   *
 *    source file wishing to use string services.            *
 *                                                           *
 *  History:                                                 *
 *  - V1.0 - 14 Mar 92                                       *
 *                                                           *
 *  Language:       Borland C++                              *
 *  System:         Gateway 386/25, MS-DOS 5.0               *
 *  Application:    CSE 784/791                              *
 *  Author:         Jim Fawcett, CST 2-127, (315)443-4454    *
 *                                                           *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#ifndef FLINES_HPP
#define FLINES_HPP
#include <fstream.h>
#include "strings.hpp"

class fline {

  protected:

    fstream ifstrm;                    // pointer to input stream
    long    position;                  // pointer to current line
    long    prev_position;             // pointer to last line
    long    top_position;              // pointer to file top

  public:

    string  str;                       // public data member

    fline(void);                       // open void line
    fline(char *filename);             // attach stream to filename
    ~fline(void);                      // destroy line
    friend int  next(fline &line);     // get another line from file
    friend int  prev(fline &line);     // get previous line from file
    friend int  done(fline &line);     // test for end of file
    friend int  eol (fline &line);     // test for end of line
    friend void rewind(fline &line);   // rewind file
    friend string collect_parens(fline &line);
				       // return parentheses string
    friend string collect_comments(fline &line);
				       // return comment string
    friend string collect_quotes(fline &line);
				       // return quoted string
};

#endif
